@@ -50,4 +50,19 @@ sub run_conditional {
     }
 }
 
+sub load_conditional {
+    my ($test_class,$predicate_class) = @_;
+    
+    SKIP :{
+        my $ok = eval {
+            Class::MOP::load_class($predicate_class);
+            use_ok($test_class);
+            return 1;
+        };
+        unless ($ok) {
+            skip "Not testing $test_class: $predicate_class is not installed",1;
+        }
+    }
+}
+
 1;
\ No newline at end of file
